==> cryptide-1.4.2.tgz: package/src/ecCurve.js <==
// Tide Protocol - Infrastructure for the Personal Data economy
// Copyright (C) 2019 Tide Foundation Ltd
// 
// This program is free software and is subject to the terms of 
// the Tide Community Open Source License as published by the 
// Tide Foundation Limited. You may modify it and redistribute 
// it in accordance with and subject to the terms of that License.
// This program is distributed WITHOUT WARRANTY of any kind, 
// including without any implied warranty of MERCHANTABILITY or 
// FITNESS FOR A PARTICULAR PURPOSE.
// See the Tide Community Open Source License for more details.
// You should have received a copy of the Tide Community Open 
// Source License along with this program.
// If not, see https://tide.org/licenses_tcosl-1-0-en

/** @typedef {string | number | BigInt.BigInteger| BN } BNInput */
import elliptic from 'elliptic';
import BigInt from 'big-integer';
import BN from 'bn.js';
import utils from './utils';

export default class EcCurve {
    get type() {return this._curve.type; }
    get p() { return this._curve.p; }
    get n() { return this._curve.n; }
    get g() { return this._curve.g; }
    get order() { return this._curve.order; }
    get infinity() { return this.point(); }

    get pCasted() { return utils.ToBig(this._curve.p); }
    get nCasted() { return utils.ToBig(this._curve.n); }

    /**@private
     * @param {elliptic.curve.base} curve
     **/
    constructor(curve) {
        this._curve = curve;
    }

    /**
     * @param {BNInput} x
     * @param {BNInput} y
     * @returns {elliptic.curve.base.BasePoint}
     */
    point(x = null, y = null) {
        if (x == null && y == null)
            // @ts-ignore
            return this._curve.point(null, null);

        if (y == null)
            // @ts-ignore
            return this._curve.pointFromX(getBN(x), false);

        // @ts-ignore
        return this._curve.point(getBN(x), getBN(y));
    }

    static secp256k1() { return new EcCurve((new elliptic.ec('secp256k1')).curve); }

    static curve25519() { return new EcCurve((new elliptic.ec('curve25519')).curve); }

    static ed25519() { return new EcCurve((new elliptic.ec('ed25519')).curve); }

    static custom25519() {
        var a = "2aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa984914a144";
        var b = "7b425ed097b425ed097b425ed097b425ed097b425ed097b4260b5e9c7710c864";
        var p = "7fffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffed";
        var n = "1000000000000000000000000000000014def9dea2f79cd65812631a5cf5d3ed";
        var gx = "2aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaad245a";
        var gy = "20ae19a1b8a086b4e01edd2c7748d14c923d4d7e6d7c61b229e9c5a27eced3d9";
        var order = "1000000000000000000000000000000014def9dea2f79cd65812631a5cf5d3ed";

        // @ts-ignore
        var curve = new elliptic.curve.short({ a, b, p, n, g: [gx, gy] });
        curve.order = new BN(order, 16);
        return new EcCurve(curve);
    }
}

/** @param {BNInput} number */
function getBN(number) {
    if (number instanceof BigInt)
        return new BN(number.toString(16));
    else if (number instanceof BN || typeof number == "string" || typeof number == "number")
        return new BN(number);
}

==> cryptide-2.0.24.tgz: package/src/ecCurve.js <==
// Tide Protocol - Infrastructure for the Personal Data economy
// Copyright (C) 2019 Tide Foundation Ltd
// 
// This program is free software and is subject to the terms of 
// the Tide Community Open Source License as published by the 
// Tide Foundation Limited. You may modify it and redistribute 
// it in accordance with and subject to the terms of that License.
// This program is distributed WITHOUT WARRANTY of any kind, 
// including without any implied warranty of MERCHANTABILITY or 
// FITNESS FOR A PARTICULAR PURPOSE.
// See the Tide Community Open Source License for more details.
// You should have received a copy of the Tide Community Open 
// Source License along with this program.
// If not, see https://tide.org/licenses_tcosl-1-0-en

import elliptic from 'elliptic';
import BigInt from 'big-integer';
import BN from 'bn.js';
import { getBig } from './bnInput';


export default class EcCurve {
    get type() {return this._curve.type; }
    get p() { return this._curve.p; }
    get n() { return this._curve.n; }
    get g() { return this._curve.g; }
    get order() { return this._curve.order; }
    get infinity() { return this.point(); }

    get pCasted() { return getBig(this._curve.p); }
    get nCasted() { return getBig(this._curve.n); }

    /**@private
     * @param {'custom'|'secp256k1'|'curve25519'|'ed25519'|'p256'} name
     * @param {elliptic.curve.base} curve
     **/
    constructor(name, curve) {
        this.name = name;
        this._curve = curve;
    }

    /**
     * @param {import('./bnInput').BNInput} x
     * @param {import('./bnInput').BNInput} y
     * @returns {elliptic.curve.base.BasePoint}
     */
    point(x = null, y = null) {
        if (x == null && y == null)
            // @ts-ignore
            return this._curve.point(null, null);

        if (y == null)
            // @ts-ignore
            return this._curve.pointFromX(getBN(x), false);

        // @ts-ignore
        return this._curve.point(getBN(x), getBN(y));
    }

    static secp256k1() { return new EcCurve('secp256k1', (new elliptic.ec('secp256k1')).curve); }

    static curve25519() { return new EcCurve('curve25519', (new elliptic.ec('curve25519')).curve); }

    static ed25519() { return new EcCurve('ed25519', (new elliptic.ec('ed25519')).curve); }

    static p256() { return new EcCurve('p256', (new elliptic.ec('p256')).curve); }

    static custom25519() {
        var a = "2aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa984914a144";
        var b = "7b425ed097b425ed097b425ed097b425ed097b425ed097b4260b5e9c7710c864";
        var p = "7fffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffed";
        var n = "1000000000000000000000000000000014def9dea2f79cd65812631a5cf5d3ed";
        var gx = "2aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaad245a";
        var gy = "20ae19a1b8a086b4e01edd2c7748d14c923d4d7e6d7c61b229e9c5a27eced3d9";
        var order = "1000000000000000000000000000000014def9dea2f79cd65812631a5cf5d3ed";

        // @ts-ignore
        var curve = new elliptic.curve.short({ a, b, p, n, g: [gx, gy] });
        curve.order = new BN(order, 16);
        return new EcCurve('custom', curve);
    }
}

/** @param {import('./bnInput').BNInput} number */
function getBN(number) {
    if (number instanceof BigInt || BigInt.isInstance(number))
        return new BN(number.toString(16), 16);
    else if (number instanceof BN || BN.isBN(number) || typeof number == "string" || typeof number == "number")
        return new BN(number);
}
